#
# spec file for package kcmutils
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# Internal QML import
%global __requires_exclude qmlimport\\(org\\.kde\\.kcmutils\\.private.*\\)

%define lname   libKF5KCMUtils5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kcmutils
Version:        5.116.0
Release:        1.2
Summary:        Classes to work with KCModules
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{_kf5_version}
BuildRequires:  cmake(KF5GuiAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5ItemViews) >= %{_kf5_version}
BuildRequires:  cmake(KF5Service) >= %{_kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{_kf5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Qml) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5QuickWidgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}

%description
KCMUtils provides various classes to work with KCModules. KCModules can be
created with the KConfigWidgets framework.

%package -n libKF5KCMUtilsCore5
Summary:        Core library of classes to work with KCModules

%description -n libKF5KCMUtilsCore5
KCMUtils provides various classes to work with KCModules. This package provides the main core library.

%package -n %{lname}
Summary:        Classes to work with KCModules
Obsoletes:      libKF5KCMUtils4

%description -n %{lname}
KCMUtils provides various classes to work with KCModules. KCModules can be
created with the KConfigWidgets framework.

%package imports
Summary:        QtQuick bindings for classes to work with KCModules
Requires:       %{lname} = %{version}
Requires:       libKF5KCMUtilsCore5 = %{version}

%description imports
KCMUtils provides various classes to work with KCModules. KCModules can be
created with the KConfigWidgets framework. This package provides QtQuick bindings
for the KCMUtils libraries.

%package devel
Summary:        Build environment for kcmutils, a set of classes to work with KCModules
Requires:       libKF5KCMUtilsCore5 = %{version}
Requires:       %{lname} = %{version}
Requires:       cmake(KF5ConfigWidgets) >= %{_kf5_version}
Requires:       cmake(KF5Service) >= %{_kf5_version}

%description devel
KCMUtils provides various classes to work with KCModules. KCModules can be
created with the KConfigWidgets framework. Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang kcmutils5

%ldconfig_scriptlets -n %{lname}

%ldconfig_scriptlets -n libKF5KCMUtilsCore5

%files -n %{lname}-lang -f kcmutils5.lang

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_libdir}/libKF5KCMUtils.so.*
%dir %{_kf5_servicetypesdir}
%{_kf5_servicetypesdir}/kcmodule.desktop
%{_kf5_servicetypesdir}/kcmoduleinit.desktop
%{_kf5_debugdir}/kcmutils.categories
%{_kf5_libexecdir}/kcmdesktopfilegenerator

%files -n libKF5KCMUtilsCore5
%{_kf5_libdir}/libKF5KCMUtilsCore.so.*

%files imports
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde/
%{_kf5_qmldir}/org/kde/kcmutils/

%files devel
%{_kf5_libdir}/libKF5KCMUtils.so
%{_kf5_libdir}/libKF5KCMUtilsCore.so
%{_kf5_libdir}/cmake/KF5KCMUtils/
%{_kf5_includedir}/KCMUtils/
%{_kf5_includedir}/KCMUtilsCore/
%{_kf5_mkspecsdir}/qt_KCMUtils.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * KCModuleQml: Set and inherit LayoutMirroring on an off-screen window
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- No code change since 5.103.0
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * KCModuleQml: Specify URL for root component's QML context
  * Fix comment: use punctuation for readability for sentences.
  * Set systemsettings as alias when generating desktop files
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Remove unused KPluginInfo includes
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- No code change since 5.100.0
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Add Qt6 windows CI support
  * Remove space
  * Fix typo
  * Kauth doesn't build on windows
  * KCModuleQML: Make sizeHint() check more robust
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Fix missing kcmutils_proxy_model export in static builds (kde#459123)
  * Launch KCMs that are not part of systemsettings in kcmshell5 (kde#458975)
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add FreeBSD Qt6 CI support
  * Use a CMake option() for the TOOLS_ONLY flag
  * KPluginSelector: Remove unnecessary background rect in About sheet (kde#457648)
  * Set Type=Application for generated KCM desktop file (kde#457673)
  * kcmoduleqml: don't unnecessarily set setContentsMargins twice
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * follow symlinks for search of .desktop files
  * tools/kcmmetadatagenerator: Print out critical warning if file could not be opened
  * Make CMake import target of kcmdesktopfilegenerator relocatable
  * Add utility cmake method to generate KCM metadata desktop files
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Remove duplicate header between cpp/h files
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * KPluginDelegate: reserve space for subtitle
  * KPluginSelector: animate placeholder appearance
  * KPluginSelector: Don't show placeholder message immediately upon load
  * KPluginSelector: fix placeholder location
  * Add debug output to print KCM location
  * AboutPlugin.qml: Do not use translation function when we only have one value
  * [kcmultidialog] Fix crash in clear()
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Fix filtering of plugin in KPluginWidget
  * Check executables exist in PATH before passing them to QProcess
  * KPluginModel: Add method to get KPluginMetaData config object for given plugin id
  * Add missing includes
  * Add SPDX headers for KPluginProxyModel files
  * Download missing licenses
  * Add docs for QML components
  * KPluginDelegate: Add configTriggered signal
  * Refactor QML components of MPluginSelector to have less dependencies and have better layout
  * KPluginModel: Add isSaveNeededChanged signal
  * Import AboutPlugin dialog from QML
  * Expose proxy sort model as private QML API
  * Create QML version of KPluginSelector
  * Allow consumers to get sort proxy model
  * Export the KPluginModel class & make it usable from QML
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Require unittests to pass for CI pipelines to pass
  * Fix KPluginSelector KCMs missing their metadata on plugin
    loading (kde#444378)
  * Mark Windows and macOS as supported
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- No code change since 5.91.0
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Add KPluginWidget::load()
  * Remove assertion for KPluginMetaData param in KCModuleLoader::loadModule
  * KCModuleProxy: Use std::optional to check if we have a KPluginMetaData object
  * Add CI qt6 support
  * Utilize ECMDeprecationSettings to manage deprecate Qt/KF API
  * KCModuleProxy: Replace space with underscore when registering DBus service
  * Switch header style to ToolBar for system settings
  * kpluginmodel: Also copy plugin Id from KService to json object
  * KCMUtils can be built on Windows too
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Remove QDesktopWidget include, not used any where
  * Change build system for building against qt6
  * Wrap deprecated KDelarative::ConfigModule::aboutData method call in
    deprecation wrappers
  * Deprecate KPluginSelector class
  * Allow KCMUtils to build without deprecated KCoreAddons methods
  * Update showNavigationButtons to use enum type
  * Fix PluginPage deprecation docs
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Set initial page using initialPage property, rather than pushing
  * Do not reset KPluginModel if there are no plugins
  * Implement KPluginSelector replacement not based around KPluginInfo
  * Do not try to unload static plugins
  * Support static plugins for X-KDE-ConfigModule property
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * KPluginSelector: Make sure to check if metaData/moduleInfo is valid before accessing it
  * KPluginSelector: Allow KCMs to be loaded using X-KDE-ConfigModule keyword
  * Remove unused internal method in KPluginSelector
  * Deprecate KCModuleInfo in favor of KPluginMetaData API
  * KCMultiDialog: Use deprecation macros to wrap internal KCModuleInfo API usage
  * KCModuleLoader: Deprecate overloads using KCModuleInfo
  * KPluginSelector: Port internally deprecated KCModuleInfo usage
  * KCModuleProxy: Deprecate KService/KCModuleInfo overloads for constructor
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * Fix Warning: Property type "Int" is not a known QVariant type
  * Add support for static builds
  * Add compat code for KService based plugin loading
  * Introduce KCModuleProxy::isChanged method
  * Un-overload KCModuleProxy:changed signal
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We depend against c++-17 so we can use qOverload directly
  * Port away from deprecated KPluginLoader
  * Minor typo and wording fixes for KCModuleInfo API doc
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Officially specify X-DocPath in the KCModule desktop file definition
  * Deprecate KCModuleProxy::aboutData
  * Add overload to pass in args in KCMultiDialog::addModule
  * Deprecate X-KDE-FactoryName and KCModuleInfo::handle
  * Deprecate KCMultiDialog::configCommitted(QByteArray) signal
  * Deprecate KSettings and KCModuleInfo based methods
  * Fix generation of documentation for deprecated methods
  * help:/ urls are already handled by KUrlHandler from KGuiAddons
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Download missing LicenseRef-KDE-Accepted-LGPL license
  * Fix loading help documentation for KPluginMetaData KCMs
  * Make KPluginMetaData accessible from KCModuleProxy class
  * Allow loading of KCModules using KPluginMetaData
  * WIP: KSettings::Dialog: port away from Dispatcher
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * [KCModuleProxy] Refactor loadModule() for simplicity
  * Force autotest as C language
  * Remove unused file
  * Port QDBusConnectionInterface::serviceOwnerChanged to QDBusServiceWatcher
  * Use new connect() signal/slot syntax
  * Remove ComponentsDialog class, not used anywhere
  * Don't forward declaration when we already include file
  * Clean up unused KPackage linking + includes
  * Deprecate unused KSettingsWidgetAdaptor class
  * kcmutils_generate_module_data: Fix moc warning in generated files
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Add loaded signal to KCModuleData to handle delayed loading
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Add .git-blame-ignore-revs file
  * Run clang-format
  * Add clang-format configuration
  * Add test for kcmutils_generate_module_data macro
  * Fix wrong margins on QML-based KCMs (kde#431855)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Ensure single column mode
  * remove window dragging hack
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Remove ifdefs, we require Qt 5.14 now
  * KPluginSelector implement default highlight indicator
  * kcmoduleqml: don't bind column width to view width (kde#428727)
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Pass parent to Q*Layout ctor instead of calling setLayout()
  * remove hack that broke multi level kcms in icon mode
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Too many changes to list here.
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Remove handling for inside events from tab hack (kde#423080)
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * KCModuleData: Fix headers, improve api doc and rename method
  * Convert header to SPDX
  * Fix KCModuleData revertToDefaults signature bool -> void
  * Extend KCModuleData with revertToDefaults and matchQuery functionnality
  * Fix typo
  * Try to avoid horizontal scrollbar in KCMultiDialog
  * Remove obsolete COPYING files
  * Add KCModuleData as base class for plugin
  * Allow extra button to be added to KPluginSelector
  * KCM-Utils: Convert copyright statements to SPDX expressions
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Support highlight indicator for QWidget and QtQuick based module
  * Add method to clear plugin selector
  * Use Qt's categorized logging, install kcmutils.categories file
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * Fix changed signal for plugin selector
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Add X-KDE-KCM-Args as property, read property in module loader
  * Repair kcmshell5 after previous commits, now with unittest
  * Add test for a "normal" KCM with desktop file
  * Rename KCModuleInfo unittest and extend it with the "fake KCM" testcase
  * Fix crash when loading an external app KCM like yast (kde#421566)
  * KSettings::Dialog: avoid duplicate entries due cascading $XDG_DATA_DIRS
- Drop upstream patches:
  * Fix-crash-when-loading-external-app.patch
  * Rename-KCModuleInfo-unittest-and-extend-it-with-fake-KCM.patch
  * Add-test-for-a-normal-KCM-with-desktop-file.patch
  * Repair-kcmshell5-after-previous-commits.patch
  * Port-these-two-to-KCModuleInfo_property-as-well.patch
* Fri May 22 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update Fix-crash-when-loading-external-app.patch to last version
  that actually was committed upstream
- Add upstream patches to fix loading normal settings modules that
  got broken by the previous fix (kde#421898), and add unit tests:
  * Rename-KCModuleInfo-unittest-and-extend-it-with-fake-KCM.patch
  * Add-test-for-a-normal-KCM-with-desktop-file.patch
  * Repair-kcmshell5-after-previous-commits.patch
  * Port-these-two-to-KCModuleInfo_property-as-well.patch
* Wed May 20 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-crash-when-loading-external-app.patch to fix loading the
  Yast entry in systemsettings (boo#1171916, kde#421566)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * KSettings::Dialog: add support for KPluginInfos without a KService
  * Small optimization: call kcmServices() only once
  * Downgrade warning about old-style KCM to qDebug, until KF6.
  * Use ecm_setup_qtplugin_macro_names
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * listen to passiveNotificationRequested
  * workaround to never make applicationitem resize itself
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Check activeModule before using it (kde#417396)
- Drop Check-activeModule-before-using-it.patch
* Sun Feb 16 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Check-activeModule-before-using-it.patch to fix crash when
  opening Kontact's settings (kde#417396)
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * prefer the new kcm plugins to the old
  * KCModuleQml: Ensure defaulted is emitted with the current
    configModule->representsDefaults on load
  * Show button respecting what is declared by KCModule
  * Update KPluginSelector to allow KCM to show good state
    for reset, apply and default button
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Deprecate KCModuleContainer
  * Remove endl. qCritical/qDebug already adds a endl.
  * Port from KDE::icon to KIconUtils for getting icon overlays
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * [KCMultiDialog] Remove most special margins handling; it's done in KPageDialog now
  * KPluginSelector: use new KAboutPluginDialog
  * Add guard for missing kirigami
  * Disable the restore defaults button if the KCModule says so
  * Have KCModuleProxy take care of the defaulted state
  * Make KCModuleQml conform to the defaulted() signal
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Conditionally show navigation buttons in the header for multi-page KCMs
  * don't use a custom header height (kde#404396)
  * Port away from deprecated SmallIcon method
  * add extra include
  * Fix memory leak of KQuickAddons::ConfigModule objects (kde#412998)
  * [KCModuleLoader] Show error when QML fails to load
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Supress mouse events in KCMs causing window moves
  * fix right border
  * adjust margins of KCMultiDialog (kde#411161)
  * [kcmutils] Port away from deprecated methods in Qt 5.14
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * Remove unused includes
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * adapt to UI changes in KPageView
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- No code changes since 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * [KCModuleQML] Fix typo breaking implicitWidth for modules
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * use size hints from the ApplicationItem itself
  * Revert "Revert "Fix Oxygen background gradient for QML modules""
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * [KCModuleLoader] Pass args to created KQuickAddons::ConfigModule
  * Pass focus to child searchbar when KPluginSelector is focused
  * [KCMUTILS] compile without foreach
  * Improve the KCM error message
  * Add runtime guard that pages are KCMs in KCMultiDialog (kde#405440)
- Dropped patches, now upstream:
  * Add-runtime-guard-that-pages-are-KCMs-in-KCMultiDialog.patch
* Wed Mar 20 2019 wbauer@tmo.at
- Add Add-runtime-guard-that-pages-are-KCMs-in-KCMultiDialog.patch
  to fix Kontact crash when opening its settings (kde#405440)
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Port deprecated methods
  * Use KCM name in KCM header
  * Add missing ifndef KCONFIGWIDGETS_NO_KAUTH
  * Fix build without kauth
  * Adapt to changes in kconfigwidgets
  * Revert "Add missing dependency on KAuth"
  * Add missing dependency on KAuth
  * Sync QML module padding to reflect system setting pages
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * [kcmutils] Add ellipsis to search labels in KPluginSelector
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * initialize variable + minor optimization
  * make use of the new currentIndex api of QML kcms
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty
  * Perfect alignment between QML and QWidget KCM titles
  * Add context to kcmodule connection to lambdas (kde#397894)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * remove deleted method
  * support for multi pages kcms
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * manage return events
  * MAke sure to build with strict compile flags
  * Manually resize KCMUtilDialog to sizeHint()
- Dropped patches, now upstream:
  * 0001-Manually-resize-KCMUtilDialog-to-sizeHint.patch
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Use custom QScrollArea with size hint not limited by font size (kde#389585)
- Dropped patches, now upstream:
  * 0001-Use-custom-QScrollArea-with-size-hint-not-limited-by.patch
- Add upstream patch 0001-Manually-resize-KCMUtilDialog-to-sizeHint.patch:
  * Workaround for QTBUG-3459 to prevent too small windows when
    system settings modules are opened standalone (kde#389585)
* Tue Aug 28 2018 fabian@ritter-vogt.de
- Add patch to fix default size of kcms (kde#389585):
  * 0001-Use-custom-QScrollArea-with-size-hint-not-limited-by.patch
* Tue Aug 21 2018 jengelh@inai.de
- Use noun phrase in summary.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * None
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * None
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * [KCModuleQml] Ignore disabled controls when tabbing
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * Warning--
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Make it possible to request a plugin configuration module programatically
  * Consistently use X-KDE-ServiceTypes instead of ServiceTypes
  * Remove not necessary QtCore and co
  * [API dox] Remove deprecated Encoding=UTF-8 from examples for desktop file
  * Add X-KDE-OnlyShowOnQtPlatforms to KCModule servicetype definition
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Adds tooltips to the two buttons on each entry
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Not necessary to use virtual keyword here
  * Prevent cmake 3.10+ warning about moc file include with KCMODULECONTAINER
  * Const'ify. Minor optimization. Port some Q_FOREACH to for(...:...)
  * it was split
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * keyboard navigation in and out QML kcms
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * no margins for qml modules from qwidget side
  * Initialize variables (found by coverity)
  * Remove dead code
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Make KCMultiDialog scrollable (kde#354227)
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Add .arconfig
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * API dox: use official name "D-Bus" consistently
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Use explicit flag constructor instead of nullptr
* Thu May 18 2017 fabian@ritter-vogt.de
- Drop kcmutils-use-susehelp.patch (boo#1039086)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * None
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * [KCModuleProxy] Remove dead code
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
  * [KCModuleQML] Pass the window as context for paletteChanged
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Use QQuickWidget for QML KCMs (kde#359124)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Fix High-DPI issue in KCMUtils
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * KPluginSelector::addPlugins: fix assert if 'config' parameter
    is default (kde#352471)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Use new json-based plugin system. KCMs are searched under kcms/.
  For now a desktop file still needs to be installed under
  kservices5/ for compatibility
  * Load and wrap the QML-only version of kcms if possible
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
- Added new BuildRequires: kpackage-devel, kdeclarative-devel,
  pkgconfig(Qt5Qml) and pkgconfig(Qt5Quick)
- Drop no longer needed Requires of the devel subpackage:
  kiconthemes-devel, kitemviews-devel and kxmlgui-devel
- Added kcmutils-use-susehelp.patch: Use susehelp wrapper, instead
  of khelpcenter command (we use khelpcenter5)
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Restore KCModule::setAuthAction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Fixed assert when dbus paths contain a '.'
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Restore KStandardGuiItems to get consistent icons and tooltips
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Fix KPluginSelector not adding non .desktop file plugins
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Fix initial size of KCMultiDialog (kde#337494, kde#325897)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kcmutils package
